****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_initmacrovariables.sas  
*
* Created (mm/dd/yyyy): 02/20/2017
* Last modified: 10/20/2018
* Version: 2.1
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*   This is a utility macro that is used to declare and initialize global macro variables                                       
*   
*  Program inputs:                                                                                   
*                                     
*  Program outputs:                                                                                                                                       
*                                                                                                  
*  PARAMETERS:    
*            
*  Programming Notes:                                                                                
*                                                                           
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*   1.1		  05/04/2017	AP		1. Added race_out, hispanic_out, agestrat cohortfile parameters
*									2. Reordered assignment of &priordays_af/bf to fix QRP-375

*	1.2		  06/26/2017	AP		1. Added Type 5 analysis
*									2. Added covariate variables to Types 3 and 4 analysis
*									3. Added EpisodeGapType to Type 2 analysis
*
*	1.3		  09/14/2017	AP		Removed Condfrom/CondTo from &inclexclvars (QRP-437)
*
*	1.4		  09/22/2017	AP		Add Condfrom/CondTo from &inclexclvars (QRP-441)
*
*	1.5	      10/03/2017	AP	 	Added keep_blackout parameter (QRP-319) and moved GEOG to Cohort File (QRP-434)
*
*	1.6	      11/20/2017	AP	 	Removed keep_blackout parameter (QRP-466)
*
*	1.7	      12/21/2017	AP	 	1. Removed comorbidity window parameters (QRP-435)
*									2. Added CODEDAYS parameter (QRP-455)
*									3. Added censoring vars to Type1file (QRP-462)
*
*	1.8	      02/01/2018	AP	 	Removed variables related to post-index enrollment (QRP-496)
*
*   1.9       02/26/2018    RR		Initialize variables related to the unexposed group (QRP-495)
*
*   1.10      02/26/2018    AP		Removed NoFindGapDuplicate macro var (QRP-305)
*
*	2.0		  05/15/2018	AP	 	Moved ms_initmacrovaribles to separate file
*									Removed var related to specific stratifications (race, hispanic, geog) from Cohortfile					
*
*	2.0		  10/20/2018	AP	 	Added GRACEDAYS and MIDAYSDIFF macro vars
*
***************************************************************************************************;

%macro ms_initmacrovariables();

	%put =====> MACRO CALLED: ms_initmacrovariables v2.0;

	*Variables related to Group(s);
	%global Group Ngroup ITGROUP cidatablesgroup count_agegroup;
	%let Group=1;
	%let Ngroup=1;
	%let ITGROUP=;
	%let cidatablesgroup = 1;

	*Variables related to COHORTFILE parameters;
	%global Type COVERAGE ENROLGAP CHARTRES RECONTYP DemogSex DemogRace DemogHispanic enrdays EnrDaysAftInd agestrat enrollmentnum numenrollgroup;
	%let Type=;
	%let COVERAGE=;
	%let ENROLGAP=;
	%let CHARTRES=;
	%let RECONTYP=;
	%let DemogSex=;
	%let DemogRace=;
	%let DemogHispanic=;
	%let enrdays=.;
	%let EnrDaysAftInd=.;
	%let agestrat=;
	%let enrollmentnum=.;
	%let numenrollgroup = 0;

	*Variables related to Query Period;
	%global startfollowup enddate nummonths numyears StartYear StartMonth EndYear EndMonth numperiodid
			ExpPeriodStartDt ExpPeriodEndDt MinExpPeriodStartDt MaxExpPeriodEndDt dpmax_adjust dpmax_check;
	%let startfollowup=.;
	%let enddate=.;
	%let nummonths=;
	%let numyears=;
	%let StartYear=;
	%let StartMonth=;
	%let EndYear=;
	%let EndMonth=;
	%let numperiodid=.;
	%let ExpPeriodStartDt=.;
	%let ExpPeriodEndDt=.;
	%let MinExpPeriodStartDt=.;
	%let MaxExpPeriodEndDt=.;
	%let dpmax_adjust=.;
	%let dpmax_check=.;

	*Variables related to TYPEFILE parameters;
	%global COHORTDEF WASHPER WASHPER2 ITT ITTDAYS eventcount FUPWASHPER BLACKOUTPER MINEPISDUR MAXEPISDUR MINDAYSUPP
		    censor_qryend censor_dpend Censor_dth censdays_value_cat t6vars EnrDaysAftEpi;
	%let COHORTDEF=;
	%let WASHPER=.;
	%let washper2=.;
	%let ITT=0;
	%let ITTDAYS=.;
	%let eventcount=.;	
	%let FUPWASHPER=.;
	%let BLACKOUTPER=.;
	%let MINEPISDUR=.;
	%let MAXEPISDUR=.;
	%let MINDAYSUPP=.;
	%let censor_qryend=.;
	%let censor_dpend=.;
	%let Censor_dth=0;
	%let censdays_value_cat = ;
	%let t6vars = ;
	%let EnrDaysAftEpi=0;

	%global neverexposedcohort;
	%let neverexposedcohort =;

	*type 3;
	%global ExclOnSameDay T3CtrlFrom T3CtrlTo T3RiskFrom T3RiskTo T3SURVSTARTDATE T3ENDOFUPDATE;  
	%let ExclOnSameDay=N;
	%let T3CtrlFrom=.;
	%let T3CtrlTo=.;
	%let T3RiskFrom=.;
	%let T3RiskTo=.;
	%let T3SURVSTARTDATE=.;
	%let T3ENDOFUPDATE=.;

	*type 4;
	%global preg NUM_MPN EnrDaysFloor T4COHORTDEF2 REMOVEMOISTART REMOVEMOIEND REMOVEMOIADATE PREPREGDAYS GRACEDAYS MIDAYSDIFF milinkage;
	%let preg = ;
	%let EnrDaysFloor=.;
	%let T4COHORTDEF2 = ;
	%let REMOVEMOISTART = .;
	%let REMOVEMOIEND = .;
	%let REMOVEMOIADATE = ;
	%let PREPREGDAYS = .;
	%let GRACEDAYS = .;
	%let MIDAYSDIFF = .;
	%let milinkage = 0;

	*Type 6;
	%global uptakedate;
	%let uptakedate=;

	*Variables related to HDPS;
	%global HDPSGROUPS MinHDPSWinfrom MaxHDPSWinTo L1HDPSFROM;
	%let HDPSGROUPS=;
	%let MinHDPSWinfrom=.;
	%let MaxHDPSWinTo=.;
	%let L1HDPSFROM=0;

	*Variables related to covariates, comorbs, MFU;
	%global MinCovFrom minMFUfrom ComborbsCodes CovarCodes CovarCodes2 NumCovars NumComb; 
	%let MinCovFrom=.;
	%let minMFUfrom=.;
	%let ComborbsCodes=;
	%let CovarCodes=;
    %let CovarCodes2=;
	%let NumCovars=0;
	%let NumComb=0;

	*Variables related to inclusion/exclusion conditions;
	%global INCL EXCL InclExclVars;
	%let INCL=0;
	%let EXCL=0;
	%let InclExclVars=;
	%if %sysfunc(exist(infolder.&INCLUSIONCODES.))=1 %then %do;
		%let InclExclVars=CondInclusion Cond Subcond SubCondInclusion condto condfrom codedays excludesupply codepop indexdate;
	%end;

	*Variables related to patients to exclude;
	%global PatIdExcl;
	%let PatIdExcl=No;
	%if %str("&PTSTOEXCLUDE.") ne %str("") %then %do;
		%let PatIdExcl=Yes;
	%end;

	*Variables related to stockpiling;
	%global SAMEDAY SUPRANGE AMTRANGE PERCENTDAYS;
	%let SAMEDAY=aa;
	%let SUPRANGE=0<-HIGH;
	%let AMTRANGE=0<-HIGH;
	%let PERCENTDAYS=;

	*Variables related to CDM and output tables;
	%global chartvar charts agedatecohort DataLib; 
	%let DataLib=indata.;

	*Initialize MILTABLE macro variable if it does not exist in Common Components;
	%if %symexist(miltable) = 0 %then %do;
		%global miltable;
		%let miltable = ;
	%end;

	*Variables related to evaluating secondary episodes;
	%global multievent concomitant overlap adherence primarygrouplist ITSANALYSIS obs_from_index obs_from_epiend obs_to_index obs_to_epiend; 
	%let multievent=0;
	%let concomitant=0;
	%let overlap=0;
	%let adherence=0;
	%let primarygrouplist=;
	%let ITSANALYSIS=0;
	%let obs_from_index = 0;
	%let obs_from_epiend = 0;
	%let obs_to_index = 0;
	%let obs_to_epiend = 0;

	*Combo Tool;
	%global COMBORUN ;
	%let COMBORUN=;

	*Variables related to USERSTRATA file;
	%global allstrat tables race_out hispanic_out geog_out geog censor_output t4_nopreggroup;
	%let allstrat = ;
	%let tables= ;
	%let race_out=;
	%let hispanic_out=;
	%let geog_out=;
	%let geog=;
	%let censor_output=N;
	%let t4_nopreggroup=N;

	*Trigger Warnings;
	%global EpisodeGapWarn;
	%let EpisodeGapWarn = N;

  %put NOTE: ******** END OF MACRO: ms_initmacrovariables v2.0 ********;

%mend ms_initmacrovariables;
