****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2_outputbaselinetable.sas  
*
* Created (mm/dd/yyyy): 12/27/2017
* Last modified: 12/18/2018
* Version: 1.4
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: The macro writes a proc report statement that produces a baseline Table 1
*                                        
*  Program inputs:                                                                                   
*
*  Program inputs:                                                                                   
* 
*  Program outputs:                                                                                                                                       
*  	- 
* 
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ----------------------------------------------------------------
*   1.1		  03/28/18	 AP			Fixed agestrat bug (QRP-564)
*
*   1.2		  04/05/18	 AP			Removed Calibri font (QRP-571)
*
*   1.3		  06/06/18	 AP			Modified for QRP 6.0.0 compatibility (USERSTRATA)
*
*   1.4		  12/18/18	 AP			Added Arial font
*									Changed name of macro from ms_outputbaselinetable to ms_t1t2_outputbaselinetable
*
***************************************************************************************************;

%macro ms_t1t2_outputbaselinetable(data=, title=);

	%put =====> MACRO CALLED: ms_t1t2_outputbaselinetable v1.4;

	/*check to see if the group is combined group*/
	proc sql;
		create table checkobs as
		select * from cohortfile
		where cohortgrp = "&group.";
	quit;				
	%let race_where = index((upcase(_name_)),'RACE') = 0;
	%let hispanic_where = index((upcase(_name_)),'HISPANIC') = 0;
	%let demographic_footnote = sex;
	%let demographic_modifier = is;

	%if "&race_out" = "Y" & "&hispanic_out" = "Y" %then %do;
		%let race_where = 1;
		%let hispanic_where = 1;
		%let demographic_footnote = sex, race, and hispanic origin;
		%let demographic_modifier = are;
	%end;
	%if "&race_out" = "Y" & "&hispanic_out" = "N" %then %do;
		%let race_where = 1;
		%let demographic_footnote = sex and race;
		%let demographic_modifier = are;
	%end;
		%if "&race_out" = "N" & "&hispanic_out" = "Y" %then %do;
		%let hispanic_where = 1;
		%let demographic_footnote = sex and hispanic origin;
		%let demographic_modifier = are;
	%end;	

	/*Assign correct age group to the group*/
	/*check agegroup for each group against cohortfile*/
	%ISDATA(dataset = checkobs);
	%if %eval(&nobs. > 0) %then %do;
	data _null_;
		set checkobs;

		if missing(agestrat) then do;
			call symputx("agestrat","00_01 02_04 05_09 10_14 15_18 19_21 22_44 45_64 65_74 75");
		end;
		else do;
			call symputx("agestrat",compress(tranwrd(agestrat,"-","_"),"+") );
		end;
	run;
	%put &agestrat.;
	%create_comma_charlist(inlist=&agestrat., outlist=agestratlist);
	%end;
	%else %do; /*combined group*/
		%if %length(&combinegroup1.) > 0 & %length(&combinegroup2.) > 0 %then %do;	
			%let group1 = %scan(&combinegroup1., %eval(&count.+1));
			%put group1 ==>&group1.;
			%let group2 = %scan(&combinegroup2., %eval(&count.+1));
			%do g = 1 %to 2;
				data _null_;
					set cohortfile;
					where cohortgrp = "&&group&g..";

					if missing(agestrat) then do;
						call symputx("agestrat&g.","00_01 02_04 05_09 10_14 15_18 19_21 22_44 45_64 65_74 75");
					end;
					else do;
						call symputx("agestrat&g.",compress(tranwrd(agestrat,"-","_"),"+") );
					end;
				run;
			%end;
		%create_comma_charlist(inlist=&agestrat1. &agestrat2., outlist=agestratlist);
		%end;
		%let count = %eval(&count. + 1);
	%end;

	data &data.;
		set &data.;
			if upcase(_label_) =: "AGE:" then do;
			  if compress(tranwrd(substr(upcase(_label_), 6), "-", "_"),"+") not in (&agestratlist) then delete;					
			end;				
		if upcase(_label_) =: "AGE:" then do;
			 %if %length(&agegroupfmt.) > 0 %then %do; 
				  _label_ = cat("Age: ", put(substr(upcase(_label_), 6), $agefmt.));
			 %end;
		end;
	run;	

	*********************************;
	********** Print Report *********;
	*********************************;

	options orientation = portrait;
	&report_header.;

	ods proclabel = "Table 1&tableletter.";

	proc report data= &data. nofs nowd spanrows split='*'
		style(header)=[rules=none background=white font_weight=bold font_size=8pt fontfamily=arial just=l vjust=b bordertopcolor=black borderbottomcolor=black] split='*'
		style(report)=[rules=none frame=box cellpadding =&line_spacing.pt];

		column ("^S={just=l}&title." (vartype _name_ grouper ("^S={background=ligr borderrightcolor=ligr}" _label_ ) ("^S={background=ligr borderleftcolor=ligr}&grouplabel." &group._a &group._b)));

		define vartype / noprint;
		define _name_ / noprint;
		define grouper / order noprint order=data '';
		define _label_ / display 'Characteristic^{super 1}' 
			style(column)=[font_size=8pt indent=10 width=3.05in fontfamily=arial] style(header)=[just=L background=white borderbottomcolor=black indent=0];
		define &group._a / display 'N/Mean'  
			style(column)=[font_size=8pt width=.85in just=R fontfamily=arial] style(header)=[just=R background=white borderbottomcolor=black];
		define &group._b / display '%/Std Dev^{super 2}'  
			style(column)=[font_size=8pt width=.85in just=R fontfamily=arial] style(header)=[just=R background=white borderbottomcolor=black];
					
		/*Add header line*/
		compute before grouper / style=[background=ligr font_size=8pt fontfamily=arial just=L font_weight=bold bordertopcolor=black borderbottomcolor=black];
			length text $100;
			if grouper = "Patient Characteristics" then do; 
				text='Demographics'; 
				num=100;
			end;
			else if grouper = "Recorded history of:" then do; 
				text='Recorded history of:'; 
				num=100; 
			end;
			else if grouper = "History of use:" then do; 
				text='History of use:';
				num=100; 
			end; 
			else if grouper = "Health Service Utilization Intensity:" then do;
				text='Health Service Utilization Intensity:';
				num=100;
			end; 	
			else if grouper = "Mahalanobis distance" then do;
				text='';
				num=100;
			end; 	
			else do; 
				text = "";
				num=0;
			end;
			line text $Varying. num; 
		endcomp;

		/*Italicize covariates*/
		%if %length(&highlight_vars.) > 0 %then %do;
			compute _label_;
			if upcase(_name_) in (&vars_to_italicize.) then do;
				call define(_row_,'style','style={fontstyle=italic}');
			end;
			endcomp;
		%end;

		/*footnote in table*/
		compute after / style=[just=L font_size=8pt bordertopcolor=black fontfamily=arial];
			line '';
			line "^{super 1}All metrics are based on total number of episodes per group, except for &demographic_footnote. which &demographic_modifier. based on total number of unique patients";
			line "^{super 2}Value represents standard deviation where no % follows the value";
		endcomp;

		where &race_where. and &hispanic_where.;
	run;

	%put =====> END MACRO: ms_t1t2_outputbaselinetable v1.4;

%mend ms_t1t2_outputbaselinetable;
