****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2_outputreport.sas  
*
* Created (mm/dd/yyyy): 12/27/2017
* Last modified: 12/15/2018 
* Version: 1.3
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: This macro produces PDF reports
* 
*  Program inputs:                                                                                   
*  	- 
* 
*  Program outputs:                                                                                                                                       
*  	- 
*
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                                                                                  
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*   1.1		  04/05/18	 AP			Removed Calibri font (QRP-571)
*
*   1.2		  07/15/18	 AP			Added covariate stratification and changed &grp to &grps
*
*   1.3		  12/15/18	 AP			Added Arial font
*									Changed macro name from ms_outputt1t2report to ms_t1t2_outputreport
*
***************************************************************************************************;

%macro ms_t1t2_outputreport();

	%put =====> MACRO CALLED: ms_t1t2_outputreport v1.3;

	ods listing close;
	ods select all;
	ods noresults;
	options nodate nonumber orientation = landscape;
	ods pdf file="&msoc./&requestid._report.pdf" pdftoc=1 ;
	ods noproctitle;
	ods escapechar="^";
	
/*--------------------------------------------------------------------------------------------*/
/* Table of Contents							 											  */
/*--------------------------------------------------------------------------------------------*/

	data tableofcontents;
		set %if "%upcase(&Output_baselinetable.)" = "Y" %then toctable1;
		 	 toc 
			%if "%upcase(&Output_CDF_KM.)" = "Y" %then Tocdfall Tockmall Toccdfall; end=eof;

			output;
			if eof then do;
				tables = "Appendix A";
				Caption = "Start and End Dates for Each Data Partner up to Request End Date (&enddate.)";
				output;
			end;
	run;

	options orientation = landscape;
	&report_header.;
	ods proclabel = "Table of Contents";

	proc report data = tableofcontents nofs nowd headline headskip split="*"
		style(header)=[rules=none background=white font_weight=bold font_size=10pt fontfamily=arial vjust=b bordertopcolor=black borderbottomcolor=black] split='*'
		style(report)=[rules=none frame=box cellpadding =&line_spacing.pt];
			
		columns ( "^S={just=C background=ligr borderrightcolor=ligr} TABLE OF CONTENTS" tables caption);			
		define tables / order=data ' '
			style(column)=[rules=none font_size=8pt font_weight=bold width= .80in just=L fontfamily=arial /*textdecoration=underline color = blue*/] ;
		define caption / order=data  ' '
			style(column)=[font_size=8pt width= 8in just=L fontfamily=arial] ;
	run;


/*--------------------------------------------------------------------------------------------*/
/* Output baseline Table							 										  */
/*--------------------------------------------------------------------------------------------*/

	%if "%upcase(&Output_baselinetable.)" = "Y" %then %do;

		%do i = %eval(&look_start) %to %eval(&look_end);
			%let tablecount = 1;
			%let tableletter = a;

			/*initialize count for combined group*/
			%let count = 0;	
			/*Loop through groups and produce 1 table per group*/
			%do grps = 1 %to &Num_allgroups.;
				%let group = %scan(&allgroups,&grps);

				/*Assign group labels from input file*/
				%let grouplabel = %scan(%bquote(&allbaselinelabel.), &grps., %str(|)); 	

			 	/*Create list of covariates to italicize and determine sort order*/
				%let highlight_vars = ;
				%let alphabetical_covarsort = N;
				data _null_;
					set &groupfile.;
						where combinegrouplabel = "&group.";
						call symputx('highlight_vars', highlight_vars);
						call symputx('alphabetical_covarsort', upcase(alphabetical_covarsort));
				run;
				%if %length(&highlight_vars.) > 0 %then %do;
					%create_comma_charlist(inlist=&highlight_vars., outlist=vars_to_italicize);
					%put &vars_to_italicize.;
				%end;

				%let covarsort = sortorder2 _name_;
				%if "&alphabetical_covarsort" = "Y" %then %let covarsort = _label_;

				proc sort data=tab_agg_l&i._&grps.; 
					by sortorder &covarsort.;
				run;		

				/*call macro to determine a)if output should have race and/or hispanic indicators*/
				/*b)assign correct age strat and change the age group format where applicable*/
				%tableletter();										
				%ms_t1t2_outputbaselinetable(data=tab_agg_l&i._&grps., title=%quote(Table 1&tableletter.. Baseline table for &grouplabel.));
			%end; /*loop trhough groups*/
		%end; /*loop through looks*/
	%end; /*end of table1*/

/*--------------------------------------------------------------------------------------------*/
/* Output Summary tables						 										      */
/*--------------------------------------------------------------------------------------------*/

	/*counter for summary tables*/
	%let sumcount = 0;
	%if "%upcase(&Output_baselinetable.)" = "Y" %then %let sumcount = 1;

	/*loop through each stratification level*/
	%do l = 1 %to %sysfunc(countw(&stratify_by_level.));
		%let level = %scan(&stratify_by_level., &l.);
		data _null_;
			category = put("%scan(&stratify_by_level., &l.)", $levelfmt.);
			call symputx("category", category);
		run;

		%let outvarlist = &varlistagg.;
		%if %str(&category.) ne %str( ) %then %do;
		%if %index(%lowcase(&category.), covar) > 0 %then %do;
			%let outvarlist = &varlistagg_nodenom.;
		%end;
		%end;

		%titles(); /*%titles is defined in t1t2table.sas*/		
		%rearrangevars(dataset = _agg_dps_summ&level.);  /*%rearrangevars is defined in utilitymacros.sas*/
		%ms_t1t2_outputt1t2table(data = _agg_dps_summ&level., 
			varlist = &outvarlist.,
			title = %bquote(Table %eval(&l.+ &sumcount.). Summary of &&labeltitle.in the Sentinel Distributed Database between &startfollowup. and &enddate. 
					%if %sysfunc(countw(&varlistagg.)) le 7 %then ^n; &&strat.), 
			var = %quote(&category.), 
			sheetname = Table %eval(&l.+&sumcount.));
	%end;

/*--------------------------------------------------------------------------------------------*/
/* Output CDF/KM PLOT    						 										      */
/*--------------------------------------------------------------------------------------------*/

	%if "%upcase(&Output_CDF_KM.)" = "Y" %then %do;
		%ms_t1t2_outputfigures();
	%end;

/*--------------------------------------------------------------------------------------------*/
/* Output Appendix A          					 										      */
/*--------------------------------------------------------------------------------------------*/

	&report_header.;
	footnote1 font=arial h =1 j=l "MinDate and MaxDate are first calculated by individual table (enrollment, dispensing, etc).";
	footnote2 font=arial h =1 j=l "MaxDate is defined as the greatest year-month with a record count that is within 80% of the previous year-month.";
	footnote3 font=arial h =1 j=l "After MinDate and MaxDates are calculated by individual tables, the overall DPMaxDate is the minimum of all the table MaxDates.";
									
	ods proclabel = "Appendix A";

	 title2 " ";
	 title3 " ";
	 title4 " ";

	proc report data = &REQUESTID._appendixa nofs nowd 
		style(header)=[rules=none background=white font_weight=bold font_size=10pt vjust=b bordertopcolor=black borderbottomcolor=black] split='*'
		style(report)=[rules=none frame=box cellpadding =&line_spacing.pt];
		
		columns ("^S={just=l background=ligr borderrightcolor=ligr}Appendix A: Start and End Dates for Each Data Partner up to Request End Date (&enddate2.)"
			MaskedID DPStartDate DPEndDate);			
		define MaskedID / Display 'Masked ID'
			style(column)=[ font_size=8pt fontfamily=arial width= 1.7in just=C] 
			style(header)=[background = darkgray font_size=10pt just=C];
		define DPStartDate / Display 'DP Start Date'
			style(column)=[font_size=8pt fontfamily=arial width= 2.0in just=C] 
			style(header)=[background = darkgray font_size=10pt just=C];
		define DPEndDate / Display 'DP End Date'
			style(column)=[ font_size=8pt fontfamily=arial width= 2.0in just=C] 
			style(header)=[background = darkgray font_size=10pt just=C];			
		run;
	
	footnote1;
	footnote2;
	footnote3;

	ods _all_ close;
	ods listing;
	ods results;

	%put =====> END MACRO: ms_t1t2_outputreport v1.3;

%mend ms_t1t2_outputreport;
	
