****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t5_create_toc.sas  
*
* Created (mm/dd/yyyy): 10/24/2017
* Last modified: 01/02/2019
* Version: 1.4
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: The macro creates a table with table number and title for table of contents
*
*  Program inputs:                                                                                   
*  	-
* 
*  Program outputs:                                                                                                                                       
*  	-
* 
*  PARAMETERS:        

*  Programming Notes:                                                                                
*                                                                           
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*   1.1 	  03/15/18   AP			Changed table 4 title (QRPL-191)
*
*   1.2	 	  03/30/18   AP			Changed tables 3 and 4 title (QRPL-203)
*  
*   1.3	      06/19/18   RT			create table contents base on users choice of tables.
*
*   1.4	      01/02/19   AP			Modified for integration into QRP
*
***************************************************************************************************;

%macro ms_t5_create_toc();

	%put =====> MACRO CALLED: ms_t5_create_toc v1.4;

	/*initialize table*/
	data TOC(where=(missing(table)=0));
		format table $20. caption $200.;
		table = '';
		caption = '';
	run;
			
	/*baseline table*/
	%if "&output_baselinetable" = "Y" %then %do;
		%let tablecount = 1;
		%let tableletter= a;
	  	%let disptablenumperiodid = ;
		
		/*loop through each look*/
		%do i = %eval(&look_start) %to %eval(&look_end);
	       %if %eval(&look_start) ne %eval(&look_end) %then %let disptablenumperiodid = (MP &i. );
		  
			%do grps = 1 %to &num_allgroups.;

				data _null_;
					set &groupfile.(where=(order=&grps.));
					call symputx("exposure", exposure);
				run;

				%tableletter;

		      	proc sql noprint;
			    	insert into toc
			    	set	table = "Table 1&tableletter."
				    , caption = "Baseline table &disptablenumperiodid.(&exposure.)";
			  quit;
		   %end;
	   %end;
	%end;

	/************/
	/** Tables **/
	/************/

	%macro distribution_title(titl=, titl1=);
	  %if %length(&titl1.)>0 %then %do;
		 %let comma=,;
	  %end;
	  %else %do;
	     %let comma=;
	  %end;
	  %if "&tablesub"="A" %then %do;
		   insert into toc
		   set	table = "Table &disptablenum."
	       ,     caption = strip("Distribution of &titl.&comma. &titl1.");
	  %end;
	  %else %if "&tablesub"="B" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
		,     caption = "Distribution of &titl., &titl1.&comma. by sex";
	  %end;
	  %else %if "&tablesub"="C" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
		,     caption = "Distribution of &titl., &titl1.&comma. by age group";
	  %end;
	  %else %if "&tablesub"="D" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			, caption = "Distribution of &titl., &titl1.&comma. by race";
	  %end;
	  %else %if "&tablesub"="E" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Distribution of &titl., &titl1.&comma. by hispanic ethnicity";
	  %end;
	  %else %if "&tablesub"="BC" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Distribution of &titl., &titl1.&comma. by sex, age group";
	  %end;
	  %else %if "&tablesub"="BD" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Distribution of &titl., &titl1.&comma. by sex, race";
	  %end;
	  %else %if "&tablesub"="BE" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Distribution of &titl., &titl1.&comma. by sex, hispanic ethnicity";
	  %end;
	  %else %if "&tablesub"="CD" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Distribution of &titl., &titl1.&comma. by age group, race";
	  %end;
	  %else %if "&tablesub"="CE" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Distribution of &titl., &titl1.&comma. by age group, hispanic ethnicity";
	  %end;
	%mend;

	%macro descriptive_title(titl=, titl1=);
	  %if %length(&titl1.)>0 %then %do;
		 %let comma=,;
	  %end;
	  %else %do;
	     %let comma=;
	  %end;
	  %if "&tablesub"="A" %then %do;
		  insert into toc
		   set	  table = "Table &disptablenum."
	    ,       caption = strip("Descriptive statistics of &titl.&comma. &titl1.");
	  %end;
	  %else %if "&tablesub"="B" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
	    ,     caption = "Descriptive statistics of &titl., &titl1.&comma. by sex";
	  %end;
	  %else %if "&tablesub"="C" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
        ,     caption = "Descriptive statistics of &titl., &titl1.&comma. by age group";
	  %end;
	  %else %if "&tablesub"="D" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
		,     caption = "Descriptive statistics of &titl., &titl1.&comma. by race";
	  %end;
	  %else %if "&tablesub"="E" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
	    ,     caption = "Descriptive statistics of &titl., &titl1.&comma. by hispanic ethnicity";
	  %end;
	  %else %if "&tablesub"="BC" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
	    ,     caption = "Descriptive statistics of &titl., &titl1.&comma. by sex, age group";
	  %end;
	  %else %if "&tablesub"="BD" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Descriptive statistics of &titl., &titl1.&comma. by sex, race";
	  %end;
	  %else %if "&tablesub"="BE" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Descriptive statistics of &titl., &titl1.&comma. by sex, hispanic ethnicity";
	  %end;
	  %else %if "&tablesub"="CD" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Descriptive statistics of &titl., &titl1.&comma. by age group, race";
	  %end;
	  %else %if "&tablesub"="CE" %then %do;
		 insert into toc
		 set	table = "Table &disptablenum."
			 ,caption = "Descriptive statistics of &titl., &titl1.&comma. by age group, hispanic ethnicity";
	  %end;

	%mend;


	/*** Create TOC for Tables ***/
	proc sort data=&tablefile.(where=(substr(table,1,1)='T')) out=_outputtables sortseq=linguistic(numeric_collation=on);
		by disptablenum;
	run;

	%isdata(dataset=_outputtables);
	%do tab=1 %to &nobs.;

		data _null_;
			set _outputtables;
			if _n_ = &tab. then do;
				call symputx('table', table);
				call symputx('tablesub', tablesub);
				call symputx('disptablenum', disptablenum);
			end;
		run;

		proc sql noprint;
		  %if &table=T2 %then %do;
		      %distribution_title(titl=%str(cumulative exposure duration, by length categories), titl1=%str(all episodes, in days));
		  %end;
		  %else %if &table=T3 %then %do;
		      %descriptive_title(titl=%str(cumulative exposure duration), titl1=%str(all episodes, in days));
		  %end;
		  %if &table=T4 %then %do;
		      %distribution_title(titl=%str(first exposure episode duration, by length categories), titl1=in days);
		  %end;
		  %else %if &table=T5 %then %do;
		      %descriptive_title(titl=%str(first exposure episode duration), titl1=in days);
		  %end;
		  %if &table=T6 %then %do;
		  	  %distribution_title(titl=%str(second and subsequent exposure episode duration, by length categories), titl1=in days);
		  %end;
		  %else %if &table=T7 %then %do;
		      %descriptive_title(titl=%str(second and subsequent exposure episode duration), titl1=in days);
		  %end;
		  %if &table=T8 %then %do;
		      %distribution_title(titl=%str(all episode durations, by length categories), titl1=in days);
		  %end;
		  %else %if &table=T9 %then %do;
		      %descriptive_title(titl=%str(all episode durations), titl1=in days);
		  %end;
		  %if &table=T10 %then %do;
		      %distribution_title(titl=%str(days supplied per dispensing, by length categories), titl1=);
		  %end;
		  %else %if &table=T11 %then %do;
		      %descriptive_title(titl=%str(days supplied per dispensing), titl1=);
		  %end;
		  %if &table=T12 %then %do;
		      %distribution_title(titl=%str(the length of the first gap between treatment episodes), titl1=in days);
		  %end;
		  %else %if &table=T13 %then %do;
		      %descriptive_title(titl=%str(the length of second and subsequent gaps between treatment episodes), titl1=in days);
		  %end;
		  %else %if &table=T14 %then %do;
		      %descriptive_title(titl=%str(the length of all gaps between treatment episodes), titl1=in days);
		  %end;
		  %else %if &table=T15 %then %do;
		      insert into toc
		      set table = "Table &disptablenum."
		,     caption = "Counts of reason for censoring, all episodes and first episode";
		  %end;
		  /*Attrition table*/
		  %else %if &table=T16 %then %do;
		      insert into toc
		      set table = "Table &disptablenum."
		,     caption = "Cohort Attrition table";
		  %end;
		;
	 	quit;
	%end;

	%macro figure_title(titl=);
	   %do grps=1 %to &num_allgroups.;

	   	     %let tabletext=%bquote(&disptablenum..&grps.);

			 data _null_;
			 	set &groupfile.(where=(order=&grps.));
				if _n_=1 then do;
				call symputx('exposure', exposure);
				end;
			run;

			proc sql noprint;
		     %if "&tablesub"="A" %then %do;
	           insert into toc
			   set	table = "Figure &tabletext."
		    ,       caption = "&titl. (&exposure.)";
		     %end;
		     %else %if "&tablesub"="B" %then %do;
	           insert into toc
			   set	  table = "Figure &tabletext."
		    ,         caption = "&titl., by sex (&exposure.)";
		     %end;
		     %else %if "&tablesub"="C" %then %do;
	           insert into toc
			   set	  table = "Figure &tabletext."
		    ,       caption = "&titl., by age group (&exposure.)";
		     %end;
		     %else %if "&tablesub"="D" %then %do;
	           insert into toc
			   set	  table = "Figure &tabletext."
		    ,       caption = "&titl., by race (&exposure.)";
		    %end;
		    %else %if "&tablesub"="E" %then %do;
	           insert into toc
			   set	  table = "Figure &tabletext."
		    ,         caption = "&titl., by hispanic ethnicity (&exposure.)";
		    %end;
			quit;
		%end;
    %mend;

	/*** Create TOC for Figures ***/
	proc sort data=&tablefile.(where=(substr(table,1,1)='F')) out=_outputfigures sortseq=linguistic(numeric_collation=on);
		by disptablenum;
	run;

	%isdata(dataset=_outputfigures);
	%do tab=1 %to &nobs.;
		data _null_;
			set _outputfigures;
			if _n_ = &tab. then do;
				call symputx('table', table);
				call symputx('tablesub', tablesub);
				call symputx('disptablenum', disptablenum);
			end;
		run;
		   %if &table=F1 %then %do;
		     %figure_title(titl=New users per month post-study start + cumulative new users per month since study start);
		   %end;
		   %else %if &table=F2 %then %do;
		     %figure_title(titl=Dispensings per month post-study start + cumulative new users per month since study start);
		   %end;
		   %else %if &table=F3 %then %do;
		     %figure_title(titl=Days supply per month post-study start + cumulative new users per month since study start);
		   %end;
		   %else %if &table=F4 %then %do;
		   	 %figure_title(titl=Survival curve for length of first treatment episode);
		   %end;
		   %else %if &table=F5 %then %do;
		   proc sql noprint;
		    insert into toc
			   set	  table = "Figure &disptablenum."
		    ,         caption = "Survival curve for length of first treatment episode (&figure5label.)";
			quit;
		    %end;
	 %end;

	 /*Appendix A*/
	 proc sql noprint;
    	insert into toc
		set	table = "Appendix A"
			  , caption = "Dates of Available Data for Each Data Partner (DP) up to Request End Date (&enddate.) as of Query Distribution Date";

	 quit;

	%put =====> END MACRO: ms_t5_create_toc v1.4;

%mend ms_t5_create_toc;
